%--------------------------------------------------------------------------
% Thermoelasticity
% Nearly incompressible Mooney Rivlin model + Mie Gruneisen equation of state
%--------------------------------------------------------------------------
function [P] = Thermoelasticity(COMP,DAT,F,H,J,Fst,Hst,Jst,Eta,ThetaR)

%--------------------------------------------------------------------------
% Preliminaries
%--------------------------------------------------------------------------
MR_Alpha           = DAT.MR_Alpha;
COMP_mu            = COMP.mu;
COMP_kappa         = COMP.kappa; 

%--------------------------------------------------------------------------
% Trace of Right Cauchy Green tensor
%--------------------------------------------------------------------------
TrC                = F(1,1)*F(1,1) + F(2,1)*F(2,1) + F(3,1)*F(3,1) + ...
                     F(1,2)*F(1,2) + F(2,2)*F(2,2) + F(3,2)*F(3,2) + ...
                     F(1,3)*F(1,3) + F(2,3)*F(2,3) + F(3,3)*F(3,3);

TrGst              = Hst(1,1)*Hst(1,1) + Hst(2,1)*Hst(2,1) + Hst(3,1)*Hst(3,1) + ...
                     Hst(1,2)*Hst(1,2) + Hst(2,2)*Hst(2,2) + Hst(3,2)*Hst(3,2) + ...
                     Hst(1,3)*Hst(1,3) + Hst(2,3)*Hst(2,3) + Hst(3,3)*Hst(3,3);

TrG                = H(1,1)*H(1,1) + H(2,1)*H(2,1) + H(3,1)*H(3,1) + ...
                     H(1,2)*H(1,2) + H(2,2)*H(2,2) + H(3,2)*H(3,2) + ...
                     H(1,3)*H(1,3) + H(2,3)*H(2,3) + H(3,3)*H(3,3);
                 
%--------------------------------------------------------------------------
% Coefficients of Mooney Rivlin model
%--------------------------------------------------------------------------
MR_Alpha                   = MR_Alpha * COMP_mu;
MR_Beta                    = (COMP_mu - 2 * MR_Alpha) /(3*sqrt(3));
        
%--------------------------------------------------------------------------
% Temperature effects
%--------------------------------------------------------------------------
Theta0                     = ThetaR * exp(- DAT.MG_gamma * (Jst^(DAT.MG_q) - 1)/DAT.MG_q);
Theta_Prime                = - DAT.MG_gamma * Jst^(DAT.MG_q - 1) * Theta0;
pressure_thermal           = DAT.Den * DAT.CF * Theta_Prime * (exp(Eta/DAT.Den/DAT.CF) - 1);

%--------------------------------------------------------------------------
% Conjugate stresses
%--------------------------------------------------------------------------
SigmaF                     = 2  * MR_Alpha   * J^(-2/3) * Fst;
SigmaH                     = 3  * MR_Beta    * J^(-2)   * TrGst^(1/2) * Hst;
SigmaJ_Hat                 = -2 * MR_Alpha/3 * Jst^(-5/3) * TrC - 2 * MR_Beta * Jst^(-3) * TrG^(3/2);
Pressure                   = COMP_kappa * (Jst - 1) + pressure_thermal;
SigmaJ                     = SigmaJ_Hat + Pressure;

%--------------------------------------------------------------------------
% First Piola
%--------------------------------------------------------------------------
P                          = SigmaF + tensor_cross_product(SigmaH, F) + SigmaJ * H; 

end